@@ -138,9 +138,10 @@ sub _fabricatePrelude {
 	my $self 	= shift;
 	my $code = "";
 	
-	$code .= "\n# Code generated by XML::Pastor at '" . localtime() . "'\n";
+	$code .= "\n#PASTOR: Code generated by XML::Pastor/" . $XML::Pastor::VERSION . " at '" . localtime() . "'\n";
 	$code .= "\nuse utf8;";
-	$code .= "\nuse strict;";		
+	$code .= "\nuse strict;";	
+#	$code .= "\nuse warnings;";	
 	$code .= "\n\nuse XML::Pastor;\n\n";	
 	return $code;	
 }
@@ -184,7 +185,10 @@ sub _fabricateCode {
 	# mk_accessors			
 	my $accessors = [];
 	if (UNIVERSAL::can($object, "attributes")) {
-		push @$accessors, @{$object->attributes()};
+		my $attribPfx = "";
+		$attribPfx = $object->attributePrefix() if (UNIVERSAL::can($object, "attributePrefix"));
+		my $fields = [map {$attribPfx . $_} @{$object->attributes()}]; 
+		push @$accessors, @$fields;
 	}
 	if (UNIVERSAL::can($object, "elements")) {
 		push @$accessors, @{$object->elements()};
@@ -192,6 +196,27 @@ sub _fabricateCode {
 	if ( scalar(@$accessors) ) {
 		$code .= "\n\n$class". '->mk_accessors( qw(' . join (' ', @$accessors) . "));";
 	}
+
+	
+	# Attribute accessor aliases
+	if (UNIVERSAL::can($object, "attributes")) {
+		my $attributes = $object->attributes(); 
+		my $attribPfx 	= (UNIVERSAL::can($object, "attributePrefix")) ? $object->attributePrefix() : "";
+		
+		if (scalar(@$attributes) && $attribPfx) {
+			$code .= "\n\n# Attribute accessor aliases\n";
+			my $elementInfo	= (UNIVERSAL::can($object, "effectiveElementInfo")) ? $object->effectiveElementInfo() : {};		
+			foreach my $attribute (@$attributes) {
+				next if defined($elementInfo->{$attribute});		# Attribute/Element name conflict. No alias possible
+				my $field = $attribPfx . $attribute;
+				next if ($field eq $attribute);					# No attribute prefix. No need for an alias.
+				$code .= "\nsub $attribute { &" . $field . '; }';
+			}		
+						
+		}
+		
+	}
+	
 	
 	# XmlSchemaInfo	
 	if (UNIVERSAL::isa($object, "XML::Pastor::Schema::Element")) {
